@@ -95,6 +95,7 @@ class AsyncAPIBase:
 
         :param token: Token对象
         :param is_sandbox: 是否沙盒环境
+        :param timeout: 设置超时时间
         """
         self.is_sandbox = is_sandbox
         self.token = token
@@ -206,11 +207,11 @@ class AsyncGuildRoleAPI(AsyncAPIBase):
         return response == ""
 
     async def delete_guild_role_member(
-        self,
-        guild_id: str,
-        role_id: str,
-        user_id: str,
-        role_req: Channel = None,
+            self,
+            guild_id: str,
+            role_id: str,
+            user_id: str,
+            role_req: Channel = None
     ) -> bool:
         """
         删除频道身份组成员
